@@ -26,6 +26,7 @@
 #include <KAboutData>
 #include <KLocalizedString>
 #include <KDBusService>
+#include <KUrlAuthorized>
 #include <QCommandLineParser>
 #include <QDebug>
 #include <QDir>
@@ -35,22 +36,27 @@ using namespace KHC;
 Application::Application(int& argc, char** argv)
     : QApplication(argc, argv), mMainWindow( 0 )
 {
-    KDBusService* s = new KDBusService(KDBusService::Unique);
-    connect(this, &Application::aboutToQuit, s, &KDBusService::deleteLater);
-    connect(s, &KDBusService::activateRequested, this, &Application::activate);
+  mCmdParser.addPositionalArgument( "url", i18n( "Documentation to open" ) );
+  mCmdParser.addHelpOption();
+  mCmdParser.addVersionOption();
+
+  // allow redirecting from internal pages to known protocols
+  KUrlAuthorized::allowUrlAction( QLatin1Literal( "redirect" ), QUrl( QLatin1Literal( "khelpcenter:" ) ), QUrl( QLatin1Literal( "ghelp:" ) ) );
+  KUrlAuthorized::allowUrlAction( QLatin1Literal( "redirect" ), QUrl( QLatin1Literal( "khelpcenter:" ) ), QUrl( QLatin1Literal( "help:" ) ) );
+  KUrlAuthorized::allowUrlAction( QLatin1Literal( "redirect" ), QUrl( QLatin1Literal( "khelpcenter:" ) ), QUrl( QLatin1Literal( "info:" ) ) );
+  KUrlAuthorized::allowUrlAction( QLatin1Literal( "redirect" ), QUrl( QLatin1Literal( "khelpcenter:" ) ), QUrl( QLatin1Literal( "man:" ) ) );
+}
+
+QCommandLineParser *Application::cmdParser()
+{
+  return &mCmdParser;
 }
 
 void Application::activate(const QStringList& args, const QString &workingDirectory)
 {
-  QCommandLineParser cmd;
-  cmd.addPositionalArgument("url", i18n("Documentation to open"));
-  cmd.addHelpOption();
-  cmd.addVersionOption();
-  KAboutData::applicationData().setupCommandLine(&cmd);
-  cmd.process(args);
-  KAboutData::applicationData().processCommandLine(&cmd);
+  mCmdParser.process( args );
 
-  QStringList urls = cmd.positionalArguments();
+  QStringList urls = mCmdParser.positionalArguments();
 
   if( !mMainWindow )
   {
@@ -61,16 +67,13 @@ void Application::activate(const QStringList& args, const QString &workingDirect
     mMainWindow = new MainWindow;
   }
 
-  foreach(const QString& arg, urls) {
-#if QT_VERSION > QT_VERSION_CHECK(5, 4, 0)
-    QUrl url = QUrl::fromUserInput(arg, workingDirectory);
-#else
-    Q_UNUSED(workingDirectory);
-    QUrl url(arg);
-#endif
-    mMainWindow->openUrl( url );
+  QUrl url;
+  if ( !urls.isEmpty() ) {
+    url = QUrl::fromUserInput( urls.at( 0 ), workingDirectory );
   }
 
+  mMainWindow->openUrl( url );
+
   mMainWindow->show();
 }
 
@@ -91,8 +94,18 @@ extern "C" int Q_DECL_EXPORT kdemain( int argc, char **argv )
   app.setWindowIcon( QIcon::fromTheme("help-browser") );
   KAboutData::setApplicationData(aboutData);
 
+  QCommandLineParser *cmd = app.cmdParser();
+  KAboutData::applicationData().setupCommandLine( cmd );
+  cmd->process( app );
+
+  KDBusService service( KDBusService::Unique );
+
+  KAboutData::applicationData().processCommandLine( cmd );
+
   app.activate(app.arguments(), QDir::currentPath());
 
+  QObject::connect( &service, &KDBusService::activateRequested, &app, &Application::activate );
+
   if ( app.isSessionRestored() )
   {
      kRestoreMainWindows<MainWindow>();
