@@ -22,13 +22,13 @@
 
 #include <QMenu>
 
-#include <KAction>
+#include <QAction>
 #include <KActionCollection>
 #include <KApplication>
 #include <KDebug>
-#include <KIcon>
+#include <QIcon>
 #include <KXmlGuiWindow>
-#include <KMenu>
+#include <QMenu>
 #include <KStandardGuiItem>
 #include <KStringHandler>
 #include <KToolBarPopupAction>
@@ -64,11 +64,11 @@ void History::setupActions( KActionCollection *coll )
 {
   QPair<KGuiItem, KGuiItem> backForward = KStandardGuiItem::backAndForward();
 
-  m_backAction = new KToolBarPopupAction( KIcon( backForward.first.iconName() ), backForward.first.text(), this );
+  m_backAction = new KToolBarPopupAction( QIcon::fromTheme( backForward.first.iconName() ), backForward.first.text(), this );
   coll->addAction( "back", m_backAction );
-  m_backAction->setShortcuts(KStandardShortcut::back());
+  coll->setDefaultShortcuts(m_backAction, KStandardShortcut::back());
   
-  connect( m_backAction, SIGNAL( triggered() ), this, SLOT( back() ) );
+  connect(m_backAction, &KToolBarPopupAction::triggered, this, &History::back);
 
   connect( m_backAction->menu(), SIGNAL( triggered( QAction* ) ),
            SLOT( backActivated( QAction* ) ) );
@@ -78,11 +78,11 @@ void History::setupActions( KActionCollection *coll )
   
   m_backAction->setEnabled( false );
 
-  m_forwardAction = new KToolBarPopupAction( KIcon( backForward.second.iconName() ), backForward.second.text(), this );
+  m_forwardAction = new KToolBarPopupAction( QIcon::fromTheme( backForward.second.iconName() ), backForward.second.text(), this );
   coll->addAction( QLatin1String("forward"), m_forwardAction );
-  m_forwardAction->setShortcuts(KStandardShortcut::forward());
+  coll->setDefaultShortcuts(m_forwardAction, KStandardShortcut::forward());
   
-  connect( m_forwardAction, SIGNAL( triggered() ), this, SLOT( forward() ) );
+  connect(m_forwardAction, &KToolBarPopupAction::triggered, this, &History::forward);
 
   connect( m_forwardAction->menu(), SIGNAL( triggered( QAction* ) ),
            SLOT( forwardActivated( QAction* ) ) );
@@ -99,10 +99,9 @@ void History::installMenuBarHook( KXmlGuiWindow *mainWindow )
       mainWindow->guiFactory()->container( QLatin1String("go_web"), mainWindow ) );
   if ( goMenu ) 
   {
-    connect( goMenu, SIGNAL( aboutToShow() ), SLOT( fillGoMenu() ) );
+    connect(goMenu, &QMenu::aboutToShow, this, &History::fillGoMenu);
     
-    connect( goMenu, SIGNAL( triggered( QAction* ) ),
-             SLOT( goMenuActivated( QAction* ) ) );
+    connect(goMenu, &QMenu::triggered, this, &History::goMenuActivated);
     
     m_goMenuIndex = goMenu->actions().count();
   }
@@ -384,5 +383,4 @@ void History::dumpHistory() const {
 
 }
 
-#include "history.moc"
 // vim:ts=2:sw=2:et
